All Classes and Interfaces

Class
Description
An AWS Arn.
 
Information that shows whether a resource is compliant with the effective tag policy, including details on any noncompliant tag keys.
 
The request failed because the target of the operation is currently being modified by a different request.
 
The request failed because performing the operation would violate a constraint.
 
 
 
 
 
 
 
 
 
 
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
 
Information about the errors that are returned for each failed resource.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Identifiers for variables declared within the rule engine, e.g.
The request processing failed because of an unknown error, exception, or failure.
 
The request failed because of one of the following reasons:
 
 
 
 
 
 
 
The request failed because the specified PaginationToken has expired.
 
 
 
 
 
 
 
 
 
Information that describes the required tags for a given resource type.
 
Service client for accessing AWS Resource Groups Tagging API asynchronously.
A builder for creating an instance of ResourceGroupsTaggingApiAsyncClient.
 
The parameters object used to resolve the auth schemes for the ResourceGroupsTaggingApi service.
An auth scheme provider for ResourceGroupsTaggingApi service.
This includes configuration specific to AWS Resource Groups Tagging API that is supported by both ResourceGroupsTaggingApiClientBuilder and ResourceGroupsTaggingApiAsyncClientBuilder.
Service client for accessing AWS Resource Groups Tagging API.
A builder for creating an instance of ResourceGroupsTaggingApiClient.
 
The parameters object used to resolve an endpoint for the ResourceGroupsTaggingApi service.
 
An endpoint provider for ResourceGroupsTaggingApi.
 
 
 
 
 
 
 
 
 
 
 
 
Class to expose the service client settings to the user.
 
A list of resource ARNs and the tags (keys and values) that are associated with each.
 
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
 
 
 
 
 
A count of noncompliant resources.
 
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them.
 
A list of tags (keys and values) that are used to specify the associated resources.
 
 
 
 
 
 
The request failed because it exceeded the allowed frequency of submitted requests.
 
 
 
 
 
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.