All Classes and Interfaces
Class
Description
An AWS Arn.
Information that shows whether a resource is compliant with the effective tag policy, including details on any
noncompliant tag keys.
The request failed because the target of the operation is currently being modified by a different request.
The request failed because performing the operation would violate a constraint.
DescribeReportCreationRequest MarshallerLink between an endpoint property and the
AwsEndpointAttribute it represents.
Information about the errors that are returned for each failed resource.
Represents the output for the
ResourceGroupsTaggingApiClient.getComplianceSummaryPaginator(software.amazon.awssdk.services.resourcegroupstaggingapi.model.GetComplianceSummaryRequest)
operation which is a paginated operation.
Represents the output for the
ResourceGroupsTaggingApiAsyncClient.getComplianceSummaryPaginator(software.amazon.awssdk.services.resourcegroupstaggingapi.model.GetComplianceSummaryRequest)
operation which is a paginated operation.GetComplianceSummaryRequest Marshaller
Represents the output for the
ResourceGroupsTaggingApiClient.getResourcesPaginator(software.amazon.awssdk.services.resourcegroupstaggingapi.model.GetResourcesRequest)
operation which is a paginated operation.
Represents the output for the
ResourceGroupsTaggingApiAsyncClient.getResourcesPaginator(software.amazon.awssdk.services.resourcegroupstaggingapi.model.GetResourcesRequest)
operation which is a paginated operation.GetResourcesRequest Marshaller
Represents the output for the
ResourceGroupsTaggingApiClient.getTagKeysPaginator(software.amazon.awssdk.services.resourcegroupstaggingapi.model.GetTagKeysRequest)
operation which is a paginated operation.
Represents the output for the
ResourceGroupsTaggingApiAsyncClient.getTagKeysPaginator(software.amazon.awssdk.services.resourcegroupstaggingapi.model.GetTagKeysRequest)
operation which is a paginated operation.GetTagKeysRequest Marshaller
Represents the output for the
ResourceGroupsTaggingApiClient.getTagValuesPaginator(software.amazon.awssdk.services.resourcegroupstaggingapi.model.GetTagValuesRequest)
operation which is a paginated operation.
Represents the output for the
ResourceGroupsTaggingApiAsyncClient.getTagValuesPaginator(software.amazon.awssdk.services.resourcegroupstaggingapi.model.GetTagValuesRequest)
operation which is a paginated operation.GetTagValuesRequest MarshallerIdentifiers for variables declared within the rule engine, e.g.
The request processing failed because of an unknown error, exception, or failure.
The request failed because of one of the following reasons:
Represents the output for the
ResourceGroupsTaggingApiClient.listRequiredTagsPaginator(software.amazon.awssdk.services.resourcegroupstaggingapi.model.ListRequiredTagsRequest)
operation which is a paginated operation.
Represents the output for the
ResourceGroupsTaggingApiAsyncClient.listRequiredTagsPaginator(software.amazon.awssdk.services.resourcegroupstaggingapi.model.ListRequiredTagsRequest)
operation which is a paginated operation.ListRequiredTagsRequest Marshaller
The request failed because the specified
PaginationToken has expired.
Information that describes the required tags for a given resource type.
Service client for accessing AWS Resource Groups Tagging API asynchronously.
A builder for creating an instance of
ResourceGroupsTaggingApiAsyncClient.The parameters object used to resolve the auth schemes for the ResourceGroupsTaggingApi service.
A builder for a
ResourceGroupsTaggingApiAuthSchemeParams.An auth scheme provider for ResourceGroupsTaggingApi service.
ResourceGroupsTaggingApiBaseClientBuilder<B extends ResourceGroupsTaggingApiBaseClientBuilder<B,C>,C>
This includes configuration specific to AWS Resource Groups Tagging API that is supported by both
ResourceGroupsTaggingApiClientBuilder and ResourceGroupsTaggingApiAsyncClientBuilder.Service client for accessing AWS Resource Groups Tagging API.
A builder for creating an instance of
ResourceGroupsTaggingApiClient.The parameters object used to resolve an endpoint for the ResourceGroupsTaggingApi service.
An endpoint provider for ResourceGroupsTaggingApi.
Class to expose the service client settings to the user.
A builder for creating a
ResourceGroupsTaggingApiServiceClientConfiguration
A list of resource ARNs and the tags (keys and values) that are associated with each.
Represents a URL to be used internally for endpoint resolution.
StartReportCreationRequest Marshaller
A count of noncompliant resources.
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them.
A list of tags (keys and values) that are used to specify the associated resources.
TagResourcesRequest Marshaller
The request failed because it exceeded the allowed frequency of submitted requests.
UntagResourcesRequest MarshallerBase class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.